Learn R Programming

fun (version 0.4)

gomoku: The game of Gomoku, a.k.a Five in a row

Description

There are two players in this game who play one after the other using black and white stones respectively. The winner is the first player to get an unbroken row of five stones horizontally, vertically, or diagonally.

Usage

gomoku(n = 19)

Value

NULL

Arguments

n

the number of rows and columns in the board (the default 19 generates the standard board)

Author

Yihui Xie <https://yihui.org>; modified from the code by pklin

References

https://d.cosx.org/d/104750, https://en.wikipedia.org/wiki/Gomoku

Examples

Run this code
gomoku()

Run the code above in your browser using DataLab