View source: R/random_password.R
| random_password | R Documentation |
This function generates a random passord sampled from the ASCII table.
random_password(length = 12, replace = FALSE, extended = TRUE)
length |
length of the password |
replace |
sample from the ASCII table with ( |
extended |
if |
a character string
Yihui Xie <https://yihui.org>
sample
random_password()
# set the seed to get fixed password every time; you may just remember the seed
# and forget the real password because it's reproducible
set.seed(123)
random_password()
# long password
random_password(20, TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.