powered by
This is a collection of R games and other funny stuff, such as the classical Mine sweeper and sliding puzzles.
Yihui Xie, Taiyun Wei, and Yixuan Qiu
New games are always welcome; if you know GIT and want to join the development, please go to https://github.com/yihui/fun; or simply contribute ideas at https://github.com/yihui/fun/issues.
Useful links:
https://github.com/yihui/fun
Report bugs at https://github.com/yihui/fun/issues
## See the examples in each function, or check out the demos demo(package = "fun")
Run the code above in your browser using DataLab