Learn R Programming

fun (version 0.4)

shutdown: Shut down the operating system with the command `shutdown'

Description

There is a command shutdown in both Windows and Linux, and this function uses it to shut down a computer.

Usage

shutdown(wait = 0)

Value

The status code of system.

Arguments

wait

time to wait before shutting down (in seconds); passed to Sys.sleep

Author

Yihui Xie <https://yihui.org>

Details

After the time wait has passed, R will execute shutdown -s -t 0 (for Windows) or shutdown -h now to shut down the computer.

See Also

Examples

Run this code
if (interactive()) {
    # when your code is extremely time-consuming, you may need this function;
    # e.g. you go to sleep, and R is running long computation... complex
    # graphics... and long long computation... at last,
    shutdown()
    # the next day you wake up, 'thank you, R' :)
}

Run the code above in your browser using DataLab